@@ -6,15 +6,8 @@ from starlette.status import HTTP_200_OK, HTTP_201_CREATED
 
 from deciphon_api.api.authentication import auth_request
 from deciphon_api.api.responses import responses
-from deciphon_api.core.errors import (
-    ConflictError,
-    InternalError,
-    ParseError,
-    UnauthorizedError,
-)
+from deciphon_api.core.errors import UnauthorizedError
 from deciphon_api.models.prod import Prod
-from deciphon_api.rc import RC
-from deciphon_api.sched.cffi import ffi, lib
 
 router = APIRouter()
 
@@ -28,7 +21,7 @@ router = APIRouter()
     name="prods:get-product",
 )
 def get_product(prod_id: int = Path(..., gt=0)):
-    return Prod.from_id(prod_id)
+    return Prod.get(prod_id)
 
 
 @router.get(
@@ -61,27 +54,5 @@ def upload_products(
         raise UnauthorizedError()
 
     prods_file.file.flush()
-    fd = os.dup(prods_file.file.fileno())
-    if fd == -1:
-        raise InternalError(RC.EFAIL, "Failed to duplicate file descriptor.")
-
-    fp = lib.fdopen(fd, b"rb")
-    if fp == ffi.NULL:
-        raise InternalError(RC.EFAIL, "Failed to fdopen a file descriptor.")
-
-    try:
-        rc = RC(lib.sched_prod_add_file(fp))
-        assert rc != RC.END
-
-        if rc == RC.EINVAL:
-            raise ConflictError("constraint violation")
-
-        if rc == RC.EPARSE:
-            raise ParseError("failed to parse file")
-
-        if rc != RC.OK:
-            raise InternalError(rc)
-    finally:
-        lib.fclose(fp)
-
+    Prod.add_file(prods_file.file)
     return []
