@@ -2,11 +2,10 @@ import typer
 import uvicorn
 
 import deciphon_api.data as data
-from deciphon_api.core.settings import get_settings
+from deciphon_api.core.settings import settings
 
 __all__ = ["run"]
 
-settings = get_settings()
 run = typer.Typer()
 
 
@@ -20,4 +19,11 @@ def start():
     host = settings.host
     port = settings.port
     log_level = settings.logging_level
-    uvicorn.run("deciphon_api.main:app.api", host=host, port=port, log_level=log_level)
+    reload = settings.reload
+    uvicorn.run(
+        "deciphon_api.main:app.api",
+        host=host,
+        port=port,
+        log_level=log_level.value,
+        reload=reload,
+    )
